##  Related Resources
User Management and Roles as basis for workspace access:
  * User management without SSO, see [Managing Users Without SSO](https://help.sap.com/docs/leanix/ea/managing-users?locale=en-US&state=PRODUCTION&version=CLOUD#loio275afeb47a441014b2a8c3973c072ba7__managing_users_without_sso)
  * User management with SSO, see [Single Sign-On (SSO)](https://help.sap.com/docs/leanix/ea/single-sign-on-sso?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to configure single sign-on \(SSO\) with SAP LeanIX.")
  * User roles, see [User Roles and Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD "Adjust role-based permissions and define custom roles.")


YesNo
Send
